==> generator-ng-poly-0.11.5.tgz: package/generators/utils/module.js <==
'use strict';

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _app = require('./app');

var _app2 = _interopRequireDefault(_app);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _getYoRcPath = require('get-yo-rc-path');

var _getYoRcPath2 = _interopRequireDefault(_getYoRcPath);

var _name = require('./name');

var _name2 = _interopRequireDefault(_name);

var _ngModGetNames = require('ng-mod-get-names');

var _ngModGetNames2 = _interopRequireDefault(_ngModGetNames);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pathExists = require('path-exists');

var _pathExists2 = _interopRequireDefault(_pathExists);

var _pify = require('pify');

var _pify2 = _interopRequireDefault(_pify);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Converts module string to key value pair {name, value} for choice
 * @param {String} module - module name
 * @return {Promise<Object>} - {name, value} of module
 */
/* eslint-disable space-before-function-paren */
function convertToChoice(module) {
  var appDir;
  return regeneratorRuntime.async(function convertToChoice$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return regeneratorRuntime.awrap(_app2.default.getAppDir());

        case 2:
          appDir = _context.sent;
          return _context.abrupt('return', {
            name: module,
            value: module.replace(appDir + '\\', '').replace(appDir + '/', '')
          });

        case 4:
        case 'end':
          return _context.stop();
      }
    }
  }, null, this);
}

/**
 * Returns modules' names in path
 * @param {String} modulePath - path to module
 * @param {String} symbol - character to split by
 * @return {Array} - module names
 */
function extractBasedOnChar(modulePath, symbol) {
  var modules = []
  // path after last symbol is module name
  ,
      moduleName = modulePath.slice(modulePath.lastIndexOf(symbol)).replace(symbol, ''),
      parentModuleName = undefined;

  modules.push(moduleName);

  // determine if user provided more than 1 symbol
  parentModuleName = modulePath.slice(0, modulePath.lastIndexOf(symbol));
  if (parentModuleName.indexOf(symbol) > -1) {
    parentModuleName = modulePath.slice(parentModuleName.lastIndexOf(symbol), modulePath.lastIndexOf(symbol));
    parentModuleName = parentModuleName.replace(symbol, '');
  }

  modules.push(parentModuleName);

  return modules;
}

/**
 * Return file path
 * @param {String} filePath - path to module MINUS the convention {,-routes,-module} and extension
 * @param {Boolean} isLookingForRoutes - looking for routes file? or just module?
 * @return {Promise<String>} file path
*/
/* eslint-disable space-before-function-paren */
function findFile(filePath, isLookingForRoutes) {
  var files, conventions, extensions;
  return regeneratorRuntime.async(function findFile$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          /* eslint-enable space-before-function-paren */
          files = [], conventions = ['-module', ''], extensions = ['coffee', 'es6', 'js', 'ts'];

          if (isLookingForRoutes) {
            conventions.unshift('-routes');
          }

          conventions.forEach(function (convention) {
            extensions.forEach(function (extension) {
              files.push(filePath + convention + '.' + extension);
            });
          });

          _context2.next = 5;
          return regeneratorRuntime.awrap(Promise.all(files.map(_pathExists2.default)));

        case 5:
          _context2.t0 = _context2.sent.indexOf(true);
          return _context2.abrupt('return', files[_context2.t0]);

        case 7:
        case 'end':
          return _context2.stop();
      }
    }
  }, null, this);
}

/**
 * Determine if file is a module file
 * @param {String} file - file name to analyze
 * @return {Boolean} - is file a module file
 */
function filterModuleFiles(file) {
  var fileBaseDirectoryWithSuffix = _path2.default.dirname(file).split(_path2.default.sep).pop() + '-module',
      fileName = _path2.default.basename(file).replace(_path2.default.extname(file), '');

  return fileName === fileBaseDirectoryWithSuffix;
}

/**
 * Determine if file is a script file
 * @param {String} file - file name to analyze
 * @return {Boolean} - is file a script file
 */
function filterScriptFiles(file) {
  return file.indexOf('.coffee') >= 0 || file.indexOf('.js') >= 0 || file.indexOf('.ts') >= 0 || file.indexOf('.es6') >= 0;
}

module.exports = {
  /**
   * Returns child and parent module names
   * @param {String} modulePath - path to module
   * @return {Promise<Object[]>} - [child, parent]
   */

  extractModuleNames: function extractModuleNames(modulePath) {
    return regeneratorRuntime.async(function extractModuleNames$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.t0 = modulePath;
            _context3.next = 3;
            return regeneratorRuntime.awrap(_app2.default.getAppDir());

          case 3:
            _context3.t1 = _context3.sent;

            if (!(_context3.t0 === _context3.t1)) {
              _context3.next = 9;
              break;
            }

            _context3.next = 7;
            return regeneratorRuntime.awrap(_app2.default.getFileFromRoot('package.json'));

          case 7:
            _context3.t2 = _context3.sent.name;
            return _context3.abrupt('return', [_context3.t2, null]);

          case 9:

            modulePath = modulePath.replace(/\\/g, '/');
            // uses module syntax

            if (!(modulePath.indexOf('/') > -1)) {
              _context3.next = 12;
              break;
            }

            return _context3.abrupt('return', extractBasedOnChar(modulePath, '/'));

          case 12:
            return _context3.abrupt('return', [modulePath, null]);

          case 13:
          case 'end':
            return _context3.stop();
        }
      }
    }, null, this);
  },

  /**
   * Returns module file path
   * @param {String} modulePath - path to module MINUS the convention {,-module} and extension
   * @return {Promise<String>} - file path
   */
  findModuleFile: function findModuleFile(modulePath) {
    var moduleFile;
    return regeneratorRuntime.async(function findModuleFile$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.next = 2;
            return regeneratorRuntime.awrap(findFile(modulePath, false));

          case 2:
            moduleFile = _context4.sent;

            if (moduleFile.indexOf('-module') === -1) {
              console.log(_chalk2.default.red('Module file names without a `-module` prefix are deprecated. Official support will be ' + 'dropped in v0.12.0. Add a `-module` prefix to be officially supported.'));
            }

            return _context4.abrupt('return', moduleFile);

          case 5:
          case 'end':
            return _context4.stop();
        }
      }
    }, null, this);
  },

  /**
   * Returns routesfile path
   * @param {String} routesPath - path to module MINUS the convention {,-routes,-module} and extension
   * @return {Promise<String>} - file path
   */
  findRoutesFile: function findRoutesFile(routesPath) {
    var routesFile;
    return regeneratorRuntime.async(function findRoutesFile$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            _context5.next = 2;
            return regeneratorRuntime.awrap(findFile(routesPath, true));

          case 2:
            routesFile = _context5.sent;

            if (routesFile.indexOf('-routes') === -1) {
              console.log(_chalk2.default.red('Routes file names without a `-routes` prefix are deprecated. Official support will be ' + 'dropped in v0.12.0. Add a `-routes` prefix to be officially supported.'));
            }

            return _context5.abrupt('return', routesFile);

          case 5:
          case 'end':
            return _context5.stop();
        }
      }
    }, null, this);
  },

  /**
   * Gets the app's name from the main module in the appDir
   * @return {Promise<String>} - app name
   */
  getAppName: function getAppName() {
    var filePath, moduleFile;
    return regeneratorRuntime.async(function getAppName$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            filePath = undefined, moduleFile = undefined;
            _context6.t0 = _path2.default;
            _context6.next = 4;
            return regeneratorRuntime.awrap(_getYoRcPath2.default.dir());

          case 4:
            _context6.t1 = _context6.sent;
            _context6.next = 7;
            return regeneratorRuntime.awrap(_app2.default.getAppDir());

          case 7:
            _context6.t2 = _context6.sent;
            filePath = _context6.t0.join.call(_context6.t0, _context6.t1, _context6.t2, 'app');
            _context6.next = 11;
            return regeneratorRuntime.awrap(this.findModuleFile(filePath));

          case 11:
            moduleFile = _context6.sent;
            _context6.next = 14;
            return regeneratorRuntime.awrap((0, _pify2.default)(_fs2.default.readFile)(moduleFile));

          case 14:
            _context6.t3 = _context6.sent.toString();
            return _context6.abrupt('return', (0, _ngModGetNames2.default)(_context6.t3)[0]);

          case 16:
          case 'end':
            return _context6.stop();
        }
      }
    }, null, this);
  },

  /**
   * Returns list of modules when given a list of files
   * @param {String[]} files - list of files to filter
   * @return {Promise<Object[]>} - list of modules
   */
  moduleFilter: function moduleFilter(files) {
    return Promise.all(_lodash2.default.uniq(files.filter(filterScriptFiles).filter(filterModuleFiles).map(function (file) {
      return _path2.default.dirname(file);
    })).map(convertToChoice));
  },

  /**
   * Converts backslashes and forwardslashes to path separator
   * @param {String} modulePath - path to module
   * @return {Promise<String>} - normalized module path
   */
  normalizeModulePath: function normalizeModulePath(modulePath) {
    return regeneratorRuntime.async(function normalizeModulePath$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            _context7.t0 = modulePath;
            _context7.next = 3;
            return regeneratorRuntime.awrap(_app2.default.getAppDir());

          case 3:
            _context7.t1 = _context7.sent;

            if (!(_context7.t0 === _context7.t1)) {
              _context7.next = 6;
              break;
            }

            return _context7.abrupt('return', '');

          case 6:
            return _context7.abrupt('return', modulePath.replace(/[\\\/]/g, _path2.default.sep).split(_path2.default.sep).map(_name2.default.hyphenName).join(_path2.default.sep));

          case 7:
          case 'end':
            return _context7.stop();
        }
      }
    }, null, this);
  }
};

==> generator-ng-poly-0.12.2.tgz: package/generators/utils/module.js <==
'use strict';

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _app = require('./app');

var _app2 = _interopRequireDefault(_app);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _getYoRcPath = require('get-yo-rc-path');

var _getYoRcPath2 = _interopRequireDefault(_getYoRcPath);

var _name = require('./name');

var _name2 = _interopRequireDefault(_name);

var _ngModGetNames = require('ng-mod-get-names');

var _ngModGetNames2 = _interopRequireDefault(_ngModGetNames);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pathExists = require('path-exists');

var _pathExists2 = _interopRequireDefault(_pathExists);

var _pify = require('pify');

var _pify2 = _interopRequireDefault(_pify);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Converts module string to key value pair {name, value} for choice
 * @param {String} module - module name
 * @return {Promise<Object>} - {name, value} of module
 */
/* eslint-disable space-before-function-paren */
function convertToChoice(module) {
  var appDir;
  return regeneratorRuntime.async(function convertToChoice$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          _context.next = 2;
          return regeneratorRuntime.awrap(_app2.default.getAppDir());

        case 2:
          appDir = _context.sent;
          return _context.abrupt('return', {
            name: module,
            value: module.replace(appDir + '\\', '').replace(appDir + '/', '')
          });

        case 4:
        case 'end':
          return _context.stop();
      }
    }
  }, null, this);
}

/**
 * Returns modules' names in path
 * @param {String} modulePath - path to module
 * @param {String} symbol - character to split by
 * @return {Array} - module names
 */
function extractBasedOnChar(modulePath, symbol) {
  var modules = []
  // path after last symbol is module name
  ,
      moduleName = modulePath.slice(modulePath.lastIndexOf(symbol)).replace(symbol, ''),
      parentModuleName = void 0;

  modules.push(moduleName);

  // determine if user provided more than 1 symbol
  parentModuleName = modulePath.slice(0, modulePath.lastIndexOf(symbol));
  if (parentModuleName.indexOf(symbol) > -1) {
    parentModuleName = modulePath.slice(parentModuleName.lastIndexOf(symbol), modulePath.lastIndexOf(symbol));
    parentModuleName = parentModuleName.replace(symbol, '');
  }

  modules.push(parentModuleName);

  return modules;
}

/**
 * Return file path
 * @param {String} filePath - path to module MINUS the convention {,-routes,-module} and extension
 * @param {Boolean} isLookingForRoutes - looking for routes file? or just module?
 * @return {Promise<String>} file path
*/
/* eslint-disable space-before-function-paren */
function findFile(filePath, isLookingForRoutes) {
  var files, conventions, extensions;
  return regeneratorRuntime.async(function findFile$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          /* eslint-enable space-before-function-paren */
          files = [], conventions = ['-module', ''], extensions = ['coffee', 'es6', 'js', 'ts'];


          if (isLookingForRoutes) {
            conventions.unshift('-routes');
          }

          conventions.forEach(function (convention) {
            extensions.forEach(function (extension) {
              files.push(filePath + convention + '.' + extension);
            });
          });

          _context2.next = 5;
          return regeneratorRuntime.awrap(Promise.all(files.map(_pathExists2.default)));

        case 5:
          _context2.t0 = _context2.sent.indexOf(true);
          return _context2.abrupt('return', files[_context2.t0]);

        case 7:
        case 'end':
          return _context2.stop();
      }
    }
  }, null, this);
}

/**
 * Determine if file is a module file
 * @param {String} file - file name to analyze
 * @return {Boolean} - is file a module file
 */
function filterModuleFiles(file) {
  var fileBaseDirectoryWithSuffix = _path2.default.dirname(file).split(_path2.default.sep).pop() + '-module',
      fileName = _path2.default.basename(file).replace(_path2.default.extname(file), '');

  return fileName === fileBaseDirectoryWithSuffix;
}

/**
 * Determine if file is a script file
 * @param {String} file - file name to analyze
 * @return {Boolean} - is file a script file
 */
function filterScriptFiles(file) {
  return file.indexOf('.coffee') >= 0 || file.indexOf('.js') >= 0 || file.indexOf('.ts') >= 0 || file.indexOf('.es6') >= 0;
}

module.exports = {
  /**
   * Returns child and parent module names
   * @param {String} modulePath - path to module
   * @return {Promise<Object[]>} - [child, parent]
   */

  extractModuleNames: function extractModuleNames(modulePath) {
    return regeneratorRuntime.async(function extractModuleNames$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.t0 = modulePath;
            _context3.next = 3;
            return regeneratorRuntime.awrap(_app2.default.getAppDir());

          case 3:
            _context3.t1 = _context3.sent;

            if (!(_context3.t0 === _context3.t1)) {
              _context3.next = 9;
              break;
            }

            _context3.next = 7;
            return regeneratorRuntime.awrap(_app2.default.getFileFromRoot('package.json'));

          case 7:
            _context3.t2 = _context3.sent.name;
            return _context3.abrupt('return', [_context3.t2, null]);

          case 9:

            modulePath = modulePath.replace(/\\/g, '/');
            // uses module syntax

            if (!(modulePath.indexOf('/') > -1)) {
              _context3.next = 12;
              break;
            }

            return _context3.abrupt('return', extractBasedOnChar(modulePath, '/'));

          case 12:
            return _context3.abrupt('return', [modulePath, null]);

          case 13:
          case 'end':
            return _context3.stop();
        }
      }
    }, null, this);
  },


  /**
   * Returns module file path
   * @param {String} modulePath - path to module MINUS the convention {,-module} and extension
   * @return {Promise<String>} - file path
   */
  findModuleFile: function findModuleFile(modulePath) {
    var moduleFile;
    return regeneratorRuntime.async(function findModuleFile$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.next = 2;
            return regeneratorRuntime.awrap(findFile(modulePath, false));

          case 2:
            moduleFile = _context4.sent;


            if (moduleFile.indexOf('-module') === -1) {
              console.log(_chalk2.default.red('Module file names without a `-module` prefix are deprecated. Official support will be ' + 'dropped in v0.12.0. Add a `-module` prefix to be officially supported.'));
            }

            return _context4.abrupt('return', moduleFile);

          case 5:
          case 'end':
            return _context4.stop();
        }
      }
    }, null, this);
  },


  /**
   * Returns routesfile path
   * @param {String} routesPath - path to module MINUS the convention {,-routes,-module} and extension
   * @return {Promise<String>} - file path
   */
  findRoutesFile: function findRoutesFile(routesPath) {
    var routesFile;
    return regeneratorRuntime.async(function findRoutesFile$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            _context5.next = 2;
            return regeneratorRuntime.awrap(findFile(routesPath, true));

          case 2:
            routesFile = _context5.sent;


            if (routesFile.indexOf('-routes') === -1) {
              console.log(_chalk2.default.red('Routes file names without a `-routes` prefix are deprecated. Official support will be ' + 'dropped in v0.12.0. Add a `-routes` prefix to be officially supported.'));
            }

            return _context5.abrupt('return', routesFile);

          case 5:
          case 'end':
            return _context5.stop();
        }
      }
    }, null, this);
  },


  /**
   * Gets the app's name from the main module in the appDir
   * @return {Promise<String>} - app name
   */
  getAppName: function getAppName() {
    var filePath, moduleFile;
    return regeneratorRuntime.async(function getAppName$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            filePath = void 0, moduleFile = void 0;
            _context6.t0 = _path2.default;
            _context6.next = 4;
            return regeneratorRuntime.awrap(_getYoRcPath2.default.dir());

          case 4:
            _context6.t1 = _context6.sent;
            _context6.next = 7;
            return regeneratorRuntime.awrap(_app2.default.getAppDir());

          case 7:
            _context6.t2 = _context6.sent;
            filePath = _context6.t0.join.call(_context6.t0, _context6.t1, _context6.t2, 'app');
            _context6.next = 11;
            return regeneratorRuntime.awrap(this.findModuleFile(filePath));

          case 11:
            moduleFile = _context6.sent;
            _context6.next = 14;
            return regeneratorRuntime.awrap((0, _pify2.default)(_fs2.default.readFile)(moduleFile));

          case 14:
            _context6.t3 = _context6.sent.toString();
            return _context6.abrupt('return', (0, _ngModGetNames2.default)(_context6.t3)[0]);

          case 16:
          case 'end':
            return _context6.stop();
        }
      }
    }, null, this);
  },


  /**
   * Returns list of modules when given a list of files
   * @param {String[]} files - list of files to filter
   * @return {Promise<Object[]>} - list of modules
   */
  moduleFilter: function moduleFilter(files) {
    return Promise.all(_lodash2.default.uniq(files.filter(filterScriptFiles).filter(filterModuleFiles).map(function (file) {
      return _path2.default.dirname(file);
    })).map(convertToChoice));
  },


  /**
   * Converts backslashes and forwardslashes to path separator
   * @param {String} modulePath - path to module
   * @return {Promise<String>} - normalized module path
   */
  normalizeModulePath: function normalizeModulePath(modulePath) {
    return regeneratorRuntime.async(function normalizeModulePath$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            _context7.t0 = modulePath;
            _context7.next = 3;
            return regeneratorRuntime.awrap(_app2.default.getAppDir());

          case 3:
            _context7.t1 = _context7.sent;

            if (!(_context7.t0 === _context7.t1)) {
              _context7.next = 6;
              break;
            }

            return _context7.abrupt('return', '');

          case 6:
            return _context7.abrupt('return', modulePath.replace(/[\\\/]/g, _path2.default.sep).split(_path2.default.sep).map(_name2.default.hyphenName).join(_path2.default.sep));

          case 7:
          case 'end':
            return _context7.stop();
        }
      }
    }, null, this);
  }
};
